clear abstract method
Future<void>
clear(
- List<
KeyPreferences< typedStoreKeys, {Object> > - List<
KeyPreferences< ? excludeKeys,Object> >
Clears values from the store by the specified typedStoreKeys.
If excludeKeys is provided, those keys will be preserved.
If typedStoreKeys is empty, all values will be cleared (except exclusions).
Implementation
Future<void> clear(
List<KeyPreferences<Object>> typedStoreKeys, {
List<KeyPreferences<Object>>? excludeKeys,
});