ValuePreferencesParserException<T> class
final
Preferences
Exception thrown when a value cannot be parsed from the store. /// This typically occurs when the stored value does not match the expected type or format defined by the KeyPreferences parser.
- Implemented types
Constructors
-
ValuePreferencesParserException(KeyPreferences<
T> key, Type type, [ValuePreferencesParser<T> ? valuePreferencesParser]) - Creates a new ValuePreferencesParserException.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
key
→ KeyPreferences<
T> -
The key that caused the exception.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Type
-
The type of the value that was expected.
final
-
valuePreferencesParser
→ ValuePreferencesParser<
T> ? -
The parser that was used to parse the value, if any.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited